From 2c7c658a23132db9452353358a9f5f6a018a6b39 Mon Sep 17 00:00:00 2001
From: Yuan-Hsin Chen <yhchen@faraday-tech.com>
Date: Fri, 31 May 2013 15:47:23 +0000
Subject: [PATCH] usb: host: fusbh200-hcd: rename two functions

Remove redundant "_fusbh200_" from fusbh200_hcd_fusbh200_probe
and fusbh200_hcd_fusbh200_remove

Signed-off-by: Yuan-Hsin Chen <yhchen@faraday-tech.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
 drivers/usb/host/fusbh200-hcd.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/usb/host/fusbh200-hcd.c b/drivers/usb/host/fusbh200-hcd.c
index bf2154d1fe55..299253c826c7 100644
--- a/drivers/usb/host/fusbh200-hcd.c
+++ b/drivers/usb/host/fusbh200-hcd.c
@@ -5782,13 +5782,13 @@ static void fusbh200_init(struct fusbh200_hcd *fusbh200)
 }
 
 /**
  * fusbh200_hcd_fusbh200_probe - initialize faraday FUSBH200 HCDs
  *
  * Allocates basic resources for this USB host controller, and
  * then invokes the start() method for the HCD associated with it
  * through the hotplug entry's driver_data.
  */
-static int fusbh200_hcd_fusbh200_probe(struct platform_device *pdev)
+static int fusbh200_hcd_probe(struct platform_device *pdev)
 {
 	struct device			*dev = &pdev->dev;
 	struct usb_hcd 			*hcd;
@@ -5886,14 +5886,14 @@ fail_create_hcd:
 }
 
 /**
  * fusbh200_hcd_fusbh200_remove - shutdown processing for EHCI HCDs
  * @dev: USB Host Controller being removed
  *
  * Reverses the effect of fotg2xx_usb_hcd_probe(), first invoking
  * the HCD's stop() method.  It is always called from a thread
  * context, normally "rmmod", "apmd", or something similar.
  */
-static int fusbh200_hcd_fusbh200_remove(struct platform_device *pdev)
+static int fusbh200_hcd_remove(struct platform_device *pdev)
 {
 	struct device *dev	= &pdev->dev;
 	struct usb_hcd *hcd	= dev_get_drvdata(dev);
@@ -5913,8 +5913,8 @@ static struct platform_driver fusbh200_hcd_fusbh200_driver = {
 	.driver = {
 		.name   = "fusbh200",
 	},
-	.probe  = fusbh200_hcd_fusbh200_probe,
-	.remove = fusbh200_hcd_fusbh200_remove,
+	.probe  = fusbh200_hcd_probe,
+	.remove = fusbh200_hcd_remove,
 };
 
 static int __init fusbh200_hcd_init(void)
@@ -5782,13 +5782,13 @@ static void fusbh200_init(struct fusbh200_hcd *fusbh200)
 
 /**
- * fusbh200_hcd_fusbh200_probe - initialize faraday FUSBH200 HCDs
+ * fusbh200_hcd_probe - initialize faraday FUSBH200 HCDs
  *
  * Allocates basic resources for this USB host controller, and
@@ -5886,14 +5886,14 @@ fail_create_hcd:
 
 /**
- * fusbh200_hcd_fusbh200_remove - shutdown processing for EHCI HCDs
+ * fusbh200_hcd_remove - shutdown processing for EHCI HCDs
  * @dev: USB Host Controller being removed
  *
-- 
2.34.1